# remirepo spec file for php-pecl-jsonpath
#
# SPDX-FileCopyrightText:  Copyright 2021-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-jsonpath}

%bcond_without      tests
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global pie_vend    supermetrics
%global pie_proj    jsonpath
%global pecl_name   jsonpath
%global ini_name    50-%{pecl_name}.ini
#global prever      RC2
%global sources     %{pecl_name}-%{version}%{?prever}
%global _configure  ../%{sources}/configure

Summary:        Extract data using JSONPath notation
Name:           %{?scl_prefix}php-pecl-jsonpath
Version:        2.1.1
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-json%{?_isa}

Provides:       %{?scl_prefix}php-%{pecl_name}                    = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}            = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})              = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}      = %{version}
Provides:       %{?scl_prefix}php-%{pie_vend}-%{pie_proj}         = %{version}
Provides:       %{?scl_prefix}php-%{pie_vend}-%{pie_proj}%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj})    = %{version}


%description
This extension allows you to use the versatile JSONPath query language to
extract the properties that you want from a decoded JSON document.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install/register tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_JSONPATH_VERSION/{s/.* "//;s/".*$//;p}' php_jsonpath.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
sed -e 's/INSTALL_ROOT/DESTDIR/' -i build/Makefile.global

cd ../NTS
%configure \
    --enable-jsonpath \
    --with-php-config=%{__phpconfig}

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --enable-jsonpath \
    --with-php-config=%{__ztsphpconfig}

%make_build
%endif


%install
%{?dtsenable}

%make_install -C NTS

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%make_install -C ZTS

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} -n \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for NTS extension
TEST_PHP_ARGS="-n -d extension=$PWD/../NTS/modules/%{pecl_name}.so" \
%{__php} -n run-tests.php -q --show-diff %{?_smp_mflags}
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} -n \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%doc %{pecl_docdir}/%{pecl_name}
%license %{sources}/LICENSE

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Sun Jan 26 2025 Remi Collet <remi@remirepo.net> - 2.1.1-1
- update to 2.1.1

* Tue Jan  9 2024 Remi Collet <remi@remirepo.net> - 2.1.0-1
- update to 2.1.0

* Tue Dec 19 2023 Remi Collet <remi@remirepo.net> - 2.0.0-1
- update to 2.0.0
- drop support for PHP 7.4

* Thu Dec 14 2023 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1
- drop patch merged upstream

* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 1.0.0-2
- build out of sources tree
- add patch for 8.3 from
  https://github.com/supermetrics-public/pecl-jsonpath/pull/169

* Mon Mar 21 2022 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0

* Thu Jan 13 2022 Remi Collet <remi@remirepo.net> - 0.9.6-1
- update to 0.9.6

* Mon Nov  1 2021 Remi Collet <remi@remirepo.net> - 0.9.5-1
- update to 0.9.5

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 0.9.4-2
- rebuild for 8.1.0RC1

* Mon Aug 23 2021 Remi Collet <remi@remirepo.net> - 0.9.4-1
- update to 0.9.4

* Mon Aug  9 2021 Remi Collet <remi@remirepo.net> - 0.9.3-1
- initial package
- open https://github.com/supermetrics-public/pecl-jsonpath/pull/137
  missing file and fix license uri
